(examples_link)=
# Examples

```{contents}
   :depth: 2
   :local:
```

Example files are found at
https://github.com/phonopy/phono3py/tree/master/example. The same are
found in the example directory of the phono3py package downloaded at
https://github.com/phonopy/phono3py/archive/master.zip.

Examples of silicon with VASP and Pwscf as calculators are given in
the `example` directory. An example using phono3py API is found in
the `example/Si-PBEsol/Si.py` but the API document has not yet written.
